# WeedCV
These tools borrows from [PlantCV](https://plantcv.danforthcenter.org/)

WeedCV is a simple tool for developing an image dataset for weed detection.

## 1. Whom does the package serve?
- Researchers
- Tech agronomists
- Image dataset developers in the natural sciences
- Students

## 2. What does the package do?
- Provide tools for developing a weed image dataset
- Faciliatates the active curation of a high-throughput data designed for automatic weed detection

## 3. Why is WeedCV useful?
- Addresses the need for large, labeled, agricultural, image datasets
_ Provides an dataset curation system capable of responding to model results

### Emphasizes:
1. Active and iterative data curation
2. Labeling that matches highthroughput demands
3. Metadata
4. Visualizations

## 4. How does WeedCV do it?
1. Dataset development
    * Annotation
    * Review
    * Metadata
    * Visualization

2. Curation 
    * Inspection
    * Reporting

